@@ -21,12 +21,10 @@
 
 #include <gsf-config.h>
 #include <gsf-gnome/gsf-input-gnomevfs.h>
+#include <gsf/gsf-input-memory.h>
 #include <gsf/gsf-input-impl.h>
 #include <gsf/gsf-impl-utils.h>
-
-#if 0
 #include <libgnomevfs/gnome-vfs-method.h>
-#endif
 
 struct _GsfInputGnomeVFS {
 	GsfInput input;
@@ -47,56 +45,111 @@ typedef GsfInputClass GsfInputGnomeVFSClass;
  *
  * Returns a new input or NULL.
  **/
-GsfInputGnomeVFS *
+GsfInput *
 gsf_input_gnomevfs_new_uri (GnomeVFSURI *uri, GError **error)
 {
-	GsfInputGnomeVFS *input;
 	GnomeVFSHandle	 *handle;
-	GnomeVFSFileInfo  info;
-	GnomeVFSResult    res = 0;
+	GnomeVFSFileInfo *info;
+	GnomeVFSResult    res;
+	GnomeVFSFileType  type;
 	gsf_off_t	  size;
-	gchar            *name;
 
-	g_return_val_if_fail (uri != NULL, NULL);
+	if (uri == NULL) {
+		g_set_error (error, gsf_input_error (), 0,
+			     "Filename/URI cannot be NULL");
+		return NULL;
+	}
 
-	res = gnome_vfs_get_file_info_uri (uri, &info, GNOME_VFS_FILE_INFO_DEFAULT);
-	if (res != GNOME_VFS_OK) {
+	if (!VFS_METHOD_HAS_FUNC (uri->method, seek))
+		goto make_local_copy;
+
+	info = gnome_vfs_file_info_new ();
+	res = gnome_vfs_get_file_info_uri (uri, info, GNOME_VFS_FILE_INFO_DEFAULT);
+	size = (gsf_off_t)info->size ;
+	type = info->type;
+	gnome_vfs_file_info_unref (info);
+
+	switch (res) {
+	case GNOME_VFS_ERROR_NOT_SUPPORTED:
+		goto make_local_copy;
+	default:
 		g_set_error (error, gsf_input_error (), (gint) res,
 			     gnome_vfs_result_to_string (res));
 		return NULL;
-	}        
-	if (info.type != GNOME_VFS_FILE_TYPE_REGULAR) {
+	case GNOME_VFS_OK: /* Nothing */ ;
+	}
+
+	if (type != GNOME_VFS_FILE_TYPE_REGULAR) {
+#if 0
+		g_print ("uri=%s\n", gnome_vfs_uri_to_string (uri, GNOME_VFS_URI_HIDE_NONE));
+		g_print ("uri.text=%s\n", uri->text);
+		g_print ("parent=%s\n", uri->parent ? gnome_vfs_uri_to_string (uri->parent, GNOME_VFS_URI_HIDE_NONE) : "(null)");
+		g_print ("method=%s\n", uri->method_string);
+		g_print ("fragment=%s\n", uri->fragment_id ? uri->fragment_id : "(null)");
+#endif
+		if (type == GNOME_VFS_FILE_TYPE_DIRECTORY && uri->parent) {
+			/* Reported for "file:///.../foo.zip#zip:beta.gnumeric" */
+			goto make_local_copy;
+		}
+
 		g_set_error (error, gsf_input_error (), 0,
 			     "Not a regular file");
 		return NULL;
 	}
 
-	res = gnome_vfs_open_uri (&handle, uri, GNOME_VFS_OPEN_READ|GNOME_VFS_OPEN_RANDOM);	
+	res = gnome_vfs_open_uri (&handle, uri,
+				  GNOME_VFS_OPEN_READ | GNOME_VFS_OPEN_RANDOM);
 	if (res != GNOME_VFS_OK) {
 		g_set_error (error, gsf_input_error (), (gint) res,
 			     gnome_vfs_result_to_string (res));
 		return NULL;
 	}
 
-#if 0
-	if (!VFS_METHOD_HAS_FUNC (uri->method, tell) ||
-	    !VFS_METHOD_HAS_FUNC (uri->method, seek)) {
-		g_warning ("no seek or tell, things may break");
+	{
+		char *name;
+		GsfInputGnomeVFS *input = g_object_new (GSF_INPUT_GNOMEVFS_TYPE, NULL);
+
+		input->handle = handle;
+		input->uri = gnome_vfs_uri_ref (uri);
+		input->buf  = NULL;
+		input->buf_size = 0;
+		gsf_input_set_size (GSF_INPUT (input), size);
+		name = gnome_vfs_uri_to_string (uri, 0);
+		gsf_input_set_name (GSF_INPUT (input), name);
+		g_free (name);
+		return GSF_INPUT (input);
 	}
-#endif
 
-	size = (gsf_off_t) info.size ;
-	input = g_object_new (GSF_INPUT_GNOMEVFS_TYPE, NULL);
-	input->handle = handle;
-	input->uri = gnome_vfs_uri_ref (uri);
-	input->buf  = NULL;
-	input->buf_size = 0;
-	gsf_input_set_size (GSF_INPUT (input), size);
-	name = gnome_vfs_uri_to_string (uri, 0);
-	gsf_input_set_name (GSF_INPUT (input), name);
-	g_free (name);
+ make_local_copy:
+	{
+		char *buffer;
+		int file_size;
+		char *uri_text, *name;
+		GsfInput *mem;
 
-	return input;
+		uri_text = gnome_vfs_uri_to_string (uri, GNOME_VFS_URI_HIDE_NONE);
+		res = gnome_vfs_read_entire_file (uri_text, &file_size, &buffer);
+		g_free (uri_text);
+		if (res != GNOME_VFS_OK) {
+			g_set_error (error, gsf_input_error (), (gint)res,
+				     "Read error while creating local copy.");
+			return NULL;
+		}
+
+		mem = gsf_input_memory_new (buffer, file_size, TRUE);
+		if (!mem) {
+			g_set_error (error, gsf_input_error (), 0,
+				     "Failed to create local memory stream");
+			g_free (buffer);
+			return NULL;
+		}
+
+		name = gnome_vfs_uri_to_string (uri, 0);
+		gsf_input_set_name (mem, name);
+		g_free (name);
+
+		return mem;
+	}
 }
 
 /**
@@ -106,13 +159,19 @@ gsf_input_gnomevfs_new_uri (GnomeVFSURI *uri, GError **error)
  *
  * Returns a new file or NULL.
  **/
-GsfInputGnomeVFS *
+GsfInput *
 gsf_input_gnomevfs_new (char const *text_uri, GError **error)
 {
-	GnomeVFSURI 	 *uri = gnome_vfs_uri_new (text_uri);
-	GsfInputGnomeVFS *res =gsf_input_gnomevfs_new_uri (uri, error);
-	gnome_vfs_uri_unref (uri);
-	return res;
+	GnomeVFSURI *uri = gnome_vfs_uri_new (text_uri);
+	if (!uri) {
+		g_set_error (error, gsf_input_error (), 0,
+			     "Invalid URI");
+		return NULL;
+	} else {
+		GsfInput *res = gsf_input_gnomevfs_new_uri (uri, error);
+		gnome_vfs_uri_unref (uri);
+		return res;
+	}
 }
 
 static void
@@ -145,7 +204,7 @@ static GsfInput *
 gsf_input_gnomevfs_dup (GsfInput *src_input, GError **err)
 {
 	GsfInputGnomeVFS const *src = (GsfInputGnomeVFS *)src_input;
-	return GSF_INPUT (gsf_input_gnomevfs_new (src->input.name, err));
+	return gsf_input_gnomevfs_new (src->input.name, err);
 }
 
 static guint8 const *
