@@ -56,7 +56,7 @@ typedef struct {
  *
  * Returns a new file or NULL.
  **/
-GsfInputStdio *
+GsfInput *
 gsf_input_stdio_new (char const *filename, GError **err)
 {
 	GsfInputStdio *input;
@@ -95,7 +95,7 @@ gsf_input_stdio_new (char const *filename, GError **err)
 	gsf_input_set_size (GSF_INPUT (input), size);
 	gsf_input_set_name (GSF_INPUT (input), filename);
 
-	return input;
+	return GSF_INPUT (input);
 }
 
 static void
@@ -123,7 +123,7 @@ static GsfInput *
 gsf_input_stdio_dup (GsfInput *src_input, GError **err)
 {
 	GsfInputStdio const *src = (GsfInputStdio *)src_input;
-	return GSF_INPUT (gsf_input_stdio_new (src->input.name, err));
+	return gsf_input_stdio_new (src->input.name, err);
 }
 
 static guint8 const *
@@ -170,7 +170,11 @@ gsf_input_stdio_seek (GsfInput *input, gsf_off_t offset, GSeekType whence)
 
 	loffset = offset;
 	if ((gsf_off_t) loffset != offset) { /* Check for overflow */
+#ifdef HAVE_FSEEKO
+		g_warning ("offset too large for fseeko");
+#else
 		g_warning ("offset too large for fseek");
+#endif
 		return TRUE;
 	}
 	switch (whence) {
@@ -181,9 +185,15 @@ gsf_input_stdio_seek (GsfInput *input, gsf_off_t offset, GSeekType whence)
 		break;
 	}
 
-	if (0 == fseek (stdio->file, (unsigned long)loffset, stdio_whence))
+	errno = 0;
+#ifdef HAVE_FSEEKO
+	if (0 == fseeko (stdio->file, loffset, stdio_whence))
 		return FALSE;
-	
+#else
+	if (0 == fseek (stdio->file, loffset, stdio_whence))
+		return FALSE;
+#endif
+	perror ("\tERROR");
 	return TRUE;
 }
 
